/*
 * jquery.mxitmarkup
 * 
 *
 * Copyright (c) 2013 Philip Perold
 * Licensed under the MIT license.
 */

(function ($) {

  var emoticons = {
      ':)'  : 'happy',
      ':('  : 'sad',
      ';)'  : 'wink',
      ':D'  : 'excited',
      ':|'  : 'shocked',
      ':o'  : 'surprised',
      ':P'  : 'smiletongue',
      ':$'  : 'embarrassed',
      '8-)' : 'cool',
      '(H)' : 'heart',
      '(F)' : 'flower',
      '(m)' : 'male',
      '(f)' : 'female',
      '(*)' : 'star',
      '(c)' : 'hot',
      '(x)' : 'kiss',
      '(i)' : 'idea',
      ':e'  : 'angry',
      ':x'  : 'consensored',
      '(z)' : 'grumpy',
      '(U)' : 'coffee',
      '(G)' : 'mrgreen',
      ':o(' : 'sick',
      ':{'  : 'astonished',
      ':}'  : 'inlove',
      '8o'  : 'rollingeyes',
      ':\'('  : 'crying',
      ':?'  : 'thinking',
      ':~'  : 'drooling',
      ':z'  : 'sleepy',
      ':L)' : 'liar',
      '8|'  : 'nerdy',
      'P-)' : 'pirate',
      ':['  : 'bored',
      ':<'  : 'cold',
      ':,'  : 'confused',
      ':C'  : 'hungry',
      ':S'  : 'stressed'
    };

  function parse(input){
    var i;

    // URL decode
    input = decodeURIComponent(input);

    // Italics
    input = input.replace(/\/(.*?)\//g,'<span style=\'font-style:italics\'>$1</span>');

    // Emoticons
    var matches = input.match(/((:-?[\)\(D\|oP$ex])|(:[\{\}\?\~z\[<,CS])|(;-?\))|:o\(|:L\)|P-\)|:'\(|(8[o|])|8-\)|\([HFmf\*cxizUG]\))/g);
    if(matches){
      for(i = 0; i < matches.length; i++){
        var emotiKey = matches[i].replace(/^\s+|\s+$/g, "");
        input = input.replace(matches[i], '<span class=\'emoticon emoticon-' + emoticons[emotiKey] + '\'></span>');
      }
    }

    // Bold
    input = input.replace(/\*(.*?)\*/g,'<span style=\'font-weight:bold\'>$1</span>');

    // Underline
    input = input.replace(/\_(.*?)\_/g,'<span style=\'text-decoration:underline\'>$1</span>');

    // Highlight (ignore highlight for now)
    input = input.replace(/\$(.*?)\$/g,'$1');

    // Bigger
    matches = input.match(/(\.\+)/g);
    if(matches){
      for(i = 0; i < matches.length; i++){
        input = input.replace(matches[i], '<span style=\'font-size:1.2em\'>') + '</span>';
      }
    }
    
    // Smaller
    matches = input.match(/(\.\-)/g);
    if(matches){
      for(i = 0; i < matches.length; i++){
        input = input.replace(matches[i], '<span style=\'font-size:0.8em\'>') + '</span>';
      }
    }

    // Spaces
    input = input.replace(/\+/g, '&nbsp;');

    // Colour
    matches = input.match(/(\#[A-Fa-f0-9]{6})/g);
    var colorKeyPairs = [];
    if(matches){
      for(i = 0; i < matches.length; i++){
        var key = '@@colorKey@@' + i;
        colorKeyPairs.push({
          key: key,
          value: matches[i]
        });
        input = input.replace(matches[i], key);
        //input = input.replace(matches[i], '<span style=\'color:' + matches[i] + '\'>') + '</span>';
      }
      for(i = 0; i < colorKeyPairs.length; i++){
        input = input.replace(colorKeyPairs[i].key, '<span style=\'color:' + colorKeyPairs[i].value + '\'>') + '</span>';
      }
    }

    return input;
  }


  // Collection method.
  $.fn.mxitmarkup = function () {
    return this.each(function() {
      $(this).html(parse($(this).html()));
    });
  };

  // Static method.
  $.mxitmarkup = function (input) {
    return parse(input);
  };


}(jQuery));
